<?php

$lan = array(

'%s users apply' => '%s users apply',
'Users marked <span class="highlight">red</span> are unconfirmed' => 'Users marked <span class="highlight">red</span> are unconfirmed',
'Show only unconfirmed users' => 'Show only unconfirmed users',
'Show only blacklisted users' => 'Show only blacklisted users',
'bouncecount' => 'bouncecount',
'foreignkey' => 'foreignkey',
'Sort by' => 'Sort by',
'asc' => 'asc',
'Go' => 'Go',
'Find a user' => 'Find a user',
'reset' => 'reset',
'Download all users as CSV file' => 'Download all users as CSV file',
'Add a User' => 'Add a User',
'bl l' => 'bl l',
'rss' => 'rss',
'bncs' => 'bncs',
'No users apply' => 'No users apply',
'Your privileges for this page are insufficient' => 'Your privileges for this page are insufficient',
'Add this user' => 'Add this user',
'Click on a link to use the corresponding public subscribe page to add this user:' => 'Click on a link to use the corresponding public subscribe page to add this user:',
'Click this link to use the public subscribe page to add this user:' => 'Click this link to use the public subscribe page to add this user:',
'%s users in total' => '%s users in total',
'too many users, use a search query to list some' => 'too many users, use a search query to list some',
'rss freq' => 'rss freq',
'last sent' => 'last sent',
'Sorry, only super users can delete users' => 'Sorry, only super users can delete users',
);
?>